# API

## Calculations

```{eval-rst}
.. module:: monkeybread.calc
.. currentmodule:: monkeybread

.. autosummary::
    :toctree: generated

    calc.cell_contact
    calc.cell_transcript_proximity
    calc.kernel_density
    calc.shortest_distances
```

## Plotting

```{eval-rst}
.. module:: monkeybread.plot
.. currentmodule:: monkeybread

.. autosummary::
    :toctree: generated

    plot.cell_contact_embedding
    plot.cell_contact_histplot
    plot.cell_contact_heatmap
    plot.cell_transcript_proximity
    plot.kernel_density
    plot.shortest_distances
    plot.volcano_plot
```

## Statistical Tests

```{eval-rst}
.. module:: monkeybread.stat
.. currentmodule:: monkeybread

.. autosummary::
    :toctree: generated

    stat.cell_contact
    stat.shortest_distances
```

## Utility Functions

```{eval-rst}
.. module:: monkeybread.util
.. currentmodule:: monkeybread

.. autosummary::
    :toctree: generated

    util.load_merscope
    util.randomize_positions
    util.subset_cells
```
